
package GLite::Data::ChannelManagement;

use strict;
no strict 'refs';
use SOAP::Lite;
use GLite::HTTPS;
use Data::Dumper;

=head1 NAME

GLite::Data::ChannelManagement

=head1 DESCRIPTION

GLite::Data::FileCatalog module provides a Perl client
library for the B<ChannelManagement> interface.

=head1 METHODS

The methods I<die> if there was a SOAP fault.
The fault string and details are added to the I<die> message.

=over 4

=item B<new($URL)>

Creates an ChannelManagement object, which is initialized with the
approriate SOAP endpoint. If the URL uses https protocol,
then it will do the HTTPS initialization (locating proxy
certificate) as well.

Note: you have to include the VO name in the URL!

    my $srv = GLite::Data::ChannelManagement->new('https://service.glite.org:8443/example');

=cut


sub new
{
    my $proto = shift;
    my $class = ref($proto) || $proto;
    my $self  = {};
    $self->{SOAP} = undef;
    bless( $self, $class );

    my $url = shift;

    defined $url or 
      print STDERR "ChannelManagement endpoint was not defined!\n" and return;

    GLite::HTTPS::setEnv() if $url =~ /^https:/i;

    $self->{SOAP} = new SOAP::Lite (
        uri => 'org.glite.data.catalog',
        proxy => $url,
        on_fault => sub { my($soap, $res) = @_;
            die $soap->transport->status, "\n" unless(ref $res);
            local $Data::Dumper::Pad = "    Details: ";
            die $res->faultcode(),": ",$res->faultstring(),"\n",
                Dumper($res->faultdetail()), "\n";
        }
    );

    
    # namespace definitions for 'http://transfer.data.glite.org'
    
    $self->{SOAP}->serializer()->maptype->{'StringPair'} = "http://transfer.data.glite.org";

    $self->{SOAP}->serializer()->maptype->{'Channel'} = "http://transfer.data.glite.org";

    $self->{SOAP}->serializer()->maptype->{'TransferException'} = "http://transfer.data.glite.org";

    $self->{SOAP}->serializer()->maptype->{'AuthorizationException'} = "http://transfer.data.glite.org";

    $self->{SOAP}->serializer()->maptype->{'ExistsException'} = "http://transfer.data.glite.org";

    $self->{SOAP}->serializer()->maptype->{'InvalidArgumentException'} = "http://transfer.data.glite.org";

    $self->{SOAP}->serializer()->maptype->{'InternalException'} = "http://transfer.data.glite.org";

    $self->{SOAP}->serializer()->maptype->{'NotExistsException'} = "http://transfer.data.glite.org";

    # namespace definitions for 'http://glite.org/wsdl/services/org.glite.data.transfer.channel'
    
    $self->{SOAP}->serializer()->maptype->{'ArrayOf_soapenc_string'} = "http://glite.org/wsdl/services/org.glite.data.transfer.channel";


    return $self;
}

    
=pod

=item B<add(Channel channel)>

=cut

sub add {
    my ($self) = shift;
    my $result = $self->{SOAP}->add(
        __serialize__Channel('channel', shift)
    )->result();
    return $result;
}

=pod

=item B<Channel getChannel(string channelName)>

=cut

sub getChannel {
    my ($self) = shift;
    my $result = $self->{SOAP}->getChannel(
        SOAP::Data->new(name => 'channelName', type => 'xsd:string', value => shift)
    )->result();
    return $result;
}

=pod

=item B<setState(string channelName, string state)>

=cut

sub setState {
    my ($self) = shift;
    my $result = $self->{SOAP}->setState(
        SOAP::Data->new(name => 'channelName', type => 'xsd:string', value => shift), 
        SOAP::Data->new(name => 'state', type => 'xsd:string', value => shift)
    )->result();
    return $result;
}

=pod

=item B<drop(string name)>

=cut

sub drop {
    my ($self) = shift;
    my $result = $self->{SOAP}->drop(
        SOAP::Data->new(name => 'name', type => 'xsd:string', value => shift)
    )->result();
    return $result;
}

=pod

=item B<string[] listChannels()>

=cut

sub listChannels {
    my ($self) = shift;
    my $result = $self->{SOAP}->listChannels(
    )->result();
    return $result;
}

=pod

=item B<changeStateForHeldJob(string jobID, string state)>

=cut

sub changeStateForHeldJob {
    my ($self) = shift;
    my $result = $self->{SOAP}->changeStateForHeldJob(
        SOAP::Data->new(name => 'jobID', type => 'xsd:string', value => shift), 
        SOAP::Data->new(name => 'state', type => 'xsd:string', value => shift)
    )->result();
    return $result;
}

=pod

=item B<changeStateForHeldJobsOnChannel(string channelName, string state)>

=cut

sub changeStateForHeldJobsOnChannel {
    my ($self) = shift;
    my $result = $self->{SOAP}->changeStateForHeldJobsOnChannel(
        SOAP::Data->new(name => 'channelName', type => 'xsd:string', value => shift), 
        SOAP::Data->new(name => 'state', type => 'xsd:string', value => shift)
    )->result();
    return $result;
}

=pod

=item B<setNumberOfStreams(string channelName, int numberOfStreams)>

=cut

sub setNumberOfStreams {
    my ($self) = shift;
    my $result = $self->{SOAP}->setNumberOfStreams(
        SOAP::Data->new(name => 'channelName', type => 'xsd:string', value => shift), 
        SOAP::Data->new(name => 'numberOfStreams', type => 'xsd:int', value => shift)
    )->result();
    return $result;
}

=pod

=item B<setNumberOfFiles(string channelName, int numberOfFiles)>

=cut

sub setNumberOfFiles {
    my ($self) = shift;
    my $result = $self->{SOAP}->setNumberOfFiles(
        SOAP::Data->new(name => 'channelName', type => 'xsd:string', value => shift), 
        SOAP::Data->new(name => 'numberOfFiles', type => 'xsd:int', value => shift)
    )->result();
    return $result;
}

=pod

=item B<setBandwidth(string channelName, int utilisation)>

=cut

sub setBandwidth {
    my ($self) = shift;
    my $result = $self->{SOAP}->setBandwidth(
        SOAP::Data->new(name => 'channelName', type => 'xsd:string', value => shift), 
        SOAP::Data->new(name => 'utilisation', type => 'xsd:int', value => shift)
    )->result();
    return $result;
}

=pod

=item B<setContact(string channelName, string contact)>

=cut

sub setContact {
    my ($self) = shift;
    my $result = $self->{SOAP}->setContact(
        SOAP::Data->new(name => 'channelName', type => 'xsd:string', value => shift), 
        SOAP::Data->new(name => 'contact', type => 'xsd:string', value => shift)
    )->result();
    return $result;
}

=pod

=item B<setNominalThroughput(string channelName, int nominalThroughput)>

=cut

sub setNominalThroughput {
    my ($self) = shift;
    my $result = $self->{SOAP}->setNominalThroughput(
        SOAP::Data->new(name => 'channelName', type => 'xsd:string', value => shift), 
        SOAP::Data->new(name => 'nominalThroughput', type => 'xsd:int', value => shift)
    )->result();
    return $result;
}

=pod

=item B<addManager(string channelName, string principal)>

=cut

sub addManager {
    my ($self) = shift;
    my $result = $self->{SOAP}->addManager(
        SOAP::Data->new(name => 'channelName', type => 'xsd:string', value => shift), 
        SOAP::Data->new(name => 'principal', type => 'xsd:string', value => shift)
    )->result();
    return $result;
}

=pod

=item B<removeManager(string channelName, string principal)>

=cut

sub removeManager {
    my ($self) = shift;
    my $result = $self->{SOAP}->removeManager(
        SOAP::Data->new(name => 'channelName', type => 'xsd:string', value => shift), 
        SOAP::Data->new(name => 'principal', type => 'xsd:string', value => shift)
    )->result();
    return $result;
}

=pod

=item B<string[] listManagers(string channelName)>

=cut

sub listManagers {
    my ($self) = shift;
    my $result = $self->{SOAP}->listManagers(
        SOAP::Data->new(name => 'channelName', type => 'xsd:string', value => shift)
    )->result();
    return $result;
}

=pod

=item B<setVOShare(string channelName, string VOName, int share)>

=cut

sub setVOShare {
    my ($self) = shift;
    my $result = $self->{SOAP}->setVOShare(
        SOAP::Data->new(name => 'channelName', type => 'xsd:string', value => shift), 
        SOAP::Data->new(name => 'VOName', type => 'xsd:string', value => shift), 
        SOAP::Data->new(name => 'share', type => 'xsd:int', value => shift)
    )->result();
    return $result;
}

=pod

=item B<string getVersion()>

=cut

sub getVersion {
    my ($self) = shift;
    my $result = $self->{SOAP}->getVersion(
    )->result();
    return $result;
}

=pod

=item B<string getSchemaVersion()>

=cut

sub getSchemaVersion {
    my ($self) = shift;
    my $result = $self->{SOAP}->getSchemaVersion(
    )->result();
    return $result;
}

=pod

=item B<string getInterfaceVersion()>

=cut

sub getInterfaceVersion {
    my ($self) = shift;
    my $result = $self->{SOAP}->getInterfaceVersion(
    )->result();
    return $result;
}

=pod

=item B<string getServiceMetadata(string key)>

=cut

sub getServiceMetadata {
    my ($self) = shift;
    my $result = $self->{SOAP}->getServiceMetadata(
        SOAP::Data->new(name => 'key', type => 'xsd:string', value => shift)
    )->result();
    return $result;
}


=pod

=back

=head1 TYPES

=over 4

=cut


    
=pod

=item B<StringPair>

    my $myStringPair = {
        string1 => 'string', 
        string2 => 'string'
    };

=cut

sub __serialize__StringPair {
    my $name     = shift; # the name of the element
    my $rawValue = shift; # the Perl structure w/o type info

    # dealing with inheritance: optional parameters from the subclass
    # calling the superclass' serializer routine with its type and fields
    my $type     = shift || 'StringPair';
    my $value    = shift || {};

    
    $value->{'string1'} = SOAP::Data->new (
        name => 'string1',
        type => 'xsd:string',
        value => $rawValue->{'string1'}
    );

    $value->{'string2'} = SOAP::Data->new (
        name => 'string2',
        type => 'xsd:string',
        value => $rawValue->{'string2'}
    );


    return SOAP::Data->new (name => $name, type => $type, value => $value);
}

=pod

=item B<Channel>

    my $myChannel = {
        channelName => 'string', 
        sourceSite => 'string', 
        destSite => 'string', 
        contact => 'string', 
        numberOfStreams => 9999, 
        numberOfFiles => 9999, 
        bandwidth => 9999, 
        nominalThroughput => 9999, 
        state => 'string', 
        VOShares => [ $myStringPair1, $myStringPair2, ... ]
    };

=cut

sub __serialize__Channel {
    my $name     = shift; # the name of the element
    my $rawValue = shift; # the Perl structure w/o type info

    # dealing with inheritance: optional parameters from the subclass
    # calling the superclass' serializer routine with its type and fields
    my $type     = shift || 'Channel';
    my $value    = shift || {};

    
    $value->{'channelName'} = SOAP::Data->new (
        name => 'channelName',
        type => 'xsd:string',
        value => $rawValue->{'channelName'}
    );

    $value->{'sourceSite'} = SOAP::Data->new (
        name => 'sourceSite',
        type => 'xsd:string',
        value => $rawValue->{'sourceSite'}
    );

    $value->{'destSite'} = SOAP::Data->new (
        name => 'destSite',
        type => 'xsd:string',
        value => $rawValue->{'destSite'}
    );

    $value->{'contact'} = SOAP::Data->new (
        name => 'contact',
        type => 'xsd:string',
        value => $rawValue->{'contact'}
    );

    $value->{'numberOfStreams'} = SOAP::Data->new (
        name => 'numberOfStreams',
        type => 'xsd:int',
        value => $rawValue->{'numberOfStreams'}
    );

    $value->{'numberOfFiles'} = SOAP::Data->new (
        name => 'numberOfFiles',
        type => 'xsd:int',
        value => $rawValue->{'numberOfFiles'}
    );

    $value->{'bandwidth'} = SOAP::Data->new (
        name => 'bandwidth',
        type => 'xsd:int',
        value => $rawValue->{'bandwidth'}
    );

    $value->{'nominalThroughput'} = SOAP::Data->new (
        name => 'nominalThroughput',
        type => 'xsd:int',
        value => $rawValue->{'nominalThroughput'}
    );

    $value->{'state'} = SOAP::Data->new (
        name => 'state',
        type => 'xsd:string',
        value => $rawValue->{'state'}
    );

    $value->{'VOShares'} = SOAP::Data->new (
        name => 'VOShares',
        type => 'SOAP-ENC:Array',
        attr => {arrayType => 'StringPair'},
        value => [ map { __serialize__StringPair(undef, $_); } @{$rawValue->{'VOShares'}} ]
    );


    return SOAP::Data->new (name => $name, type => $type, value => $value);
}

=pod

=item B<TransferException>

    my $myTransferException = {
        message => 'string'
    };

=cut

sub __serialize__TransferException {
    my $name     = shift; # the name of the element
    my $rawValue = shift; # the Perl structure w/o type info

    # dealing with inheritance: optional parameters from the subclass
    # calling the superclass' serializer routine with its type and fields
    my $type     = shift || 'TransferException';
    my $value    = shift || {};

    
    $value->{'message'} = SOAP::Data->new (
        name => 'message',
        type => 'xsd:string',
        value => $rawValue->{'message'}
    );


    return SOAP::Data->new (name => $name, type => $type, value => $value);
}

=pod

=item B<AuthorizationException>

    my $myAuthorizationException = new TransferException (
        
    );

=cut

sub __serialize__AuthorizationException {
    my $name     = shift; # the name of the element
    my $rawValue = shift; # the Perl structure w/o type info

    # dealing with inheritance: optional parameters from the subclass
    # calling the superclass' serializer routine with its type and fields
    my $type     = shift || 'AuthorizationException';
    my $value    = shift || {};

    

    # calling the superclass' serializer for the rest
    return __serialize__TransferException ($name, $rawValue, $type, $value);
}

=pod

=item B<ExistsException>

    my $myExistsException = new TransferException (
        
    );

=cut

sub __serialize__ExistsException {
    my $name     = shift; # the name of the element
    my $rawValue = shift; # the Perl structure w/o type info

    # dealing with inheritance: optional parameters from the subclass
    # calling the superclass' serializer routine with its type and fields
    my $type     = shift || 'ExistsException';
    my $value    = shift || {};

    

    # calling the superclass' serializer for the rest
    return __serialize__TransferException ($name, $rawValue, $type, $value);
}

=pod

=item B<InvalidArgumentException>

    my $myInvalidArgumentException = new TransferException (
        
    );

=cut

sub __serialize__InvalidArgumentException {
    my $name     = shift; # the name of the element
    my $rawValue = shift; # the Perl structure w/o type info

    # dealing with inheritance: optional parameters from the subclass
    # calling the superclass' serializer routine with its type and fields
    my $type     = shift || 'InvalidArgumentException';
    my $value    = shift || {};

    

    # calling the superclass' serializer for the rest
    return __serialize__TransferException ($name, $rawValue, $type, $value);
}

=pod

=item B<InternalException>

    my $myInternalException = new TransferException (
        
    );

=cut

sub __serialize__InternalException {
    my $name     = shift; # the name of the element
    my $rawValue = shift; # the Perl structure w/o type info

    # dealing with inheritance: optional parameters from the subclass
    # calling the superclass' serializer routine with its type and fields
    my $type     = shift || 'InternalException';
    my $value    = shift || {};

    

    # calling the superclass' serializer for the rest
    return __serialize__TransferException ($name, $rawValue, $type, $value);
}

=pod

=item B<NotExistsException>

    my $myNotExistsException = new TransferException (
        
    );

=cut

sub __serialize__NotExistsException {
    my $name     = shift; # the name of the element
    my $rawValue = shift; # the Perl structure w/o type info

    # dealing with inheritance: optional parameters from the subclass
    # calling the superclass' serializer routine with its type and fields
    my $type     = shift || 'NotExistsException';
    my $value    = shift || {};

    

    # calling the superclass' serializer for the rest
    return __serialize__TransferException ($name, $rawValue, $type, $value);
}

=pod

=item B<ArrayOf_soapenc_string>

    my $myArrayOf_soapenc_string = [ 'string1', 'string2', ...];

=cut

sub __serialize__ArrayOf_soapenc_string {
    my $name     = shift; # the name of the element
    my $rawValue = shift; # the Perl array w/o type info
    my $type     = 'ArrayOf_soapenc_string';
    my $value    = {};

    return SOAP::Data->new (
        name => $name,
        type => 'SOAP-ENC:Array',
        attr => {arrayType => 'xsd:string'},
        value => [ map { SOAP::Data->new(type => 'xsd:string', value => $_); } @{$rawValue} ]
    );
}



=pod

=back

=head1 SEE ALSO

L<GLite::HTTPS>

=head1 AUTHORS

Copyright (c) 2004 CERN, on behalf of the EU EGEE project.
For license conditions see LICENSE file or
L<http://www.edg.org/license.html>.

=cut

1;
