
package GLite::Data::FileTransfer;

use strict;
no strict 'refs';
use SOAP::Lite;
use GLite::HTTPS;
use Data::Dumper;

=head1 NAME

GLite::Data::FileTransfer

=head1 DESCRIPTION

GLite::Data::FileCatalog module provides a Perl client
library for the B<FileTransfer> interface.

=head1 METHODS

The methods I<die> if there was a SOAP fault.
The fault string and details are added to the I<die> message.

=over 4

=item B<new($URL)>

Creates an FileTransfer object, which is initialized with the
approriate SOAP endpoint. If the URL uses https protocol,
then it will do the HTTPS initialization (locating proxy
certificate) as well.

Note: you have to include the VO name in the URL!

    my $srv = GLite::Data::FileTransfer->new('https://service.glite.org:8443/example');

=cut


sub new
{
    my $proto = shift;
    my $class = ref($proto) || $proto;
    my $self  = {};
    $self->{SOAP} = undef;
    bless( $self, $class );

    my $url = shift;

    defined $url or 
      print STDERR "FileTransfer endpoint was not defined!\n" and return;

    GLite::HTTPS::setEnv() if $url =~ /^https:/i;

    $self->{SOAP} = new SOAP::Lite (
        uri => 'org.glite.data.catalog',
        proxy => $url,
        on_fault => sub { my($soap, $res) = @_;
            die $soap->transport->status, "\n" unless(ref $res);
            local $Data::Dumper::Pad = "    Details: ";
            die $res->faultcode(),": ",$res->faultstring(),"\n",
                Dumper($res->faultdetail()), "\n";
        }
    );

    
    # namespace definitions for 'http://transfer.data.glite.org'
    
    $self->{SOAP}->serializer()->maptype->{'TransferParams'} = "http://transfer.data.glite.org";

    $self->{SOAP}->serializer()->maptype->{'PlacementJob'} = "http://transfer.data.glite.org";

    $self->{SOAP}->serializer()->maptype->{'TransferException'} = "http://transfer.data.glite.org";

    $self->{SOAP}->serializer()->maptype->{'InvalidArgumentException'} = "http://transfer.data.glite.org";

    $self->{SOAP}->serializer()->maptype->{'AuthorizationException'} = "http://transfer.data.glite.org";

    $self->{SOAP}->serializer()->maptype->{'ServiceBusyException'} = "http://transfer.data.glite.org";

    $self->{SOAP}->serializer()->maptype->{'InternalException'} = "http://transfer.data.glite.org";

    $self->{SOAP}->serializer()->maptype->{'TransferJobElement'} = "http://transfer.data.glite.org";

    $self->{SOAP}->serializer()->maptype->{'TransferJob'} = "http://transfer.data.glite.org";

    $self->{SOAP}->serializer()->maptype->{'JobStatus'} = "http://transfer.data.glite.org";

    $self->{SOAP}->serializer()->maptype->{'FileTransferStatus'} = "http://transfer.data.glite.org";

    $self->{SOAP}->serializer()->maptype->{'NotExistsException'} = "http://transfer.data.glite.org";

    $self->{SOAP}->serializer()->maptype->{'TransferJobSummary'} = "http://transfer.data.glite.org";

    $self->{SOAP}->serializer()->maptype->{'CannotCancelException'} = "http://transfer.data.glite.org";

    $self->{SOAP}->serializer()->maptype->{'ExistsException'} = "http://transfer.data.glite.org";

    $self->{SOAP}->serializer()->maptype->{'StringPair'} = "http://transfer.data.glite.org";

    $self->{SOAP}->serializer()->maptype->{'Roles'} = "http://transfer.data.glite.org";

    # namespace definitions for 'http://glite.org/wsdl/services/org.glite.data.transfer.fts'
    
    $self->{SOAP}->serializer()->maptype->{'ArrayOf_soapenc_string'} = "http://glite.org/wsdl/services/org.glite.data.transfer.fts";

    $self->{SOAP}->serializer()->maptype->{'ArrayOf_tns3_JobStatus'} = "http://glite.org/wsdl/services/org.glite.data.transfer.fts";

    $self->{SOAP}->serializer()->maptype->{'ArrayOf_tns3_FileTransferStatus'} = "http://glite.org/wsdl/services/org.glite.data.transfer.fts";


    return $self;
}

    
=pod

=item B<string placementSubmit(PlacementJob job)>

=cut

sub placementSubmit {
    my ($self) = shift;
    my $result = $self->{SOAP}->placementSubmit(
        __serialize__PlacementJob('job', shift)
    )->result();
    return $result;
}

=pod

=item B<string transferSubmit(TransferJob job)>

=cut

sub transferSubmit {
    my ($self) = shift;
    my $result = $self->{SOAP}->transferSubmit(
        __serialize__TransferJob('job', shift)
    )->result();
    return $result;
}

=pod

=item B<string submit(TransferJob job)>

=cut

sub submit {
    my ($self) = shift;
    my $result = $self->{SOAP}->submit(
        __serialize__TransferJob('job', shift)
    )->result();
    return $result;
}

=pod

=item B<JobStatus[] listRequests(string[] inGivenStates, string channelName)>

=cut

sub listRequests {
    my ($self) = shift;
    my $result = $self->{SOAP}->listRequests(
        __serialize__ArrayOf_soapenc_string('inGivenStates', shift), 
        SOAP::Data->new(name => 'channelName', type => 'xsd:string', value => shift)
    )->result();
    return $result;
}

=pod

=item B<FileTransferStatus[] getFileStatus(string requestID, int offset, int limit)>

=cut

sub getFileStatus {
    my ($self) = shift;
    my $result = $self->{SOAP}->getFileStatus(
        SOAP::Data->new(name => 'requestID', type => 'xsd:string', value => shift), 
        SOAP::Data->new(name => 'offset', type => 'xsd:int', value => shift), 
        SOAP::Data->new(name => 'limit', type => 'xsd:int', value => shift)
    )->result();
    return $result;
}

=pod

=item B<JobStatus getTransferJobStatus(string requestID)>

=cut

sub getTransferJobStatus {
    my ($self) = shift;
    my $result = $self->{SOAP}->getTransferJobStatus(
        SOAP::Data->new(name => 'requestID', type => 'xsd:string', value => shift)
    )->result();
    return $result;
}

=pod

=item B<TransferJobSummary getTransferJobSummary(string requestID)>

=cut

sub getTransferJobSummary {
    my ($self) = shift;
    my $result = $self->{SOAP}->getTransferJobSummary(
        SOAP::Data->new(name => 'requestID', type => 'xsd:string', value => shift)
    )->result();
    return $result;
}

=pod

=item B<cancel(string[] requestIDs)>

=cut

sub cancel {
    my ($self) = shift;
    my $result = $self->{SOAP}->cancel(
        __serialize__ArrayOf_soapenc_string('requestIDs', shift)
    )->result();
    return $result;
}

=pod

=item B<setJobPriority(string requestID, int priority)>

=cut

sub setJobPriority {
    my ($self) = shift;
    my $result = $self->{SOAP}->setJobPriority(
        SOAP::Data->new(name => 'requestID', type => 'xsd:string', value => shift), 
        SOAP::Data->new(name => 'priority', type => 'xsd:int', value => shift)
    )->result();
    return $result;
}

=pod

=item B<addVOManager(string VOName, string principal)>

=cut

sub addVOManager {
    my ($self) = shift;
    my $result = $self->{SOAP}->addVOManager(
        SOAP::Data->new(name => 'VOName', type => 'xsd:string', value => shift), 
        SOAP::Data->new(name => 'principal', type => 'xsd:string', value => shift)
    )->result();
    return $result;
}

=pod

=item B<removeVOManager(string VOName, string principal)>

=cut

sub removeVOManager {
    my ($self) = shift;
    my $result = $self->{SOAP}->removeVOManager(
        SOAP::Data->new(name => 'VOName', type => 'xsd:string', value => shift), 
        SOAP::Data->new(name => 'principal', type => 'xsd:string', value => shift)
    )->result();
    return $result;
}

=pod

=item B<string[] listVOManagers(string VOName)>

=cut

sub listVOManagers {
    my ($self) = shift;
    my $result = $self->{SOAP}->listVOManagers(
        SOAP::Data->new(name => 'VOName', type => 'xsd:string', value => shift)
    )->result();
    return $result;
}

=pod

=item B<Roles getRoles()>

=cut

sub getRoles {
    my ($self) = shift;
    my $result = $self->{SOAP}->getRoles(
    )->result();
    return $result;
}

=pod

=item B<string getVersion()>

=cut

sub getVersion {
    my ($self) = shift;
    my $result = $self->{SOAP}->getVersion(
    )->result();
    return $result;
}

=pod

=item B<string getSchemaVersion()>

=cut

sub getSchemaVersion {
    my ($self) = shift;
    my $result = $self->{SOAP}->getSchemaVersion(
    )->result();
    return $result;
}

=pod

=item B<string getInterfaceVersion()>

=cut

sub getInterfaceVersion {
    my ($self) = shift;
    my $result = $self->{SOAP}->getInterfaceVersion(
    )->result();
    return $result;
}

=pod

=item B<string getServiceMetadata(string key)>

=cut

sub getServiceMetadata {
    my ($self) = shift;
    my $result = $self->{SOAP}->getServiceMetadata(
        SOAP::Data->new(name => 'key', type => 'xsd:string', value => shift)
    )->result();
    return $result;
}


=pod

=back

=head1 TYPES

=over 4

=cut


    
=pod

=item B<TransferParams>

    my $myTransferParams = {
        keys => [ 'string1', 'string2', ... ], 
        values => [ 'string1', 'string2', ... ]
    };

=cut

sub __serialize__TransferParams {
    my $name     = shift; # the name of the element
    my $rawValue = shift; # the Perl structure w/o type info

    # dealing with inheritance: optional parameters from the subclass
    # calling the superclass' serializer routine with its type and fields
    my $type     = shift || 'TransferParams';
    my $value    = shift || {};

    
    $value->{'keys'} = SOAP::Data->new (
        name => 'keys',
        type => 'SOAP-ENC:Array',
        attr => {arrayType => 'xsd:string'},
        value => [ map { SOAP::Data->new(type => 'xsd:string', value => $_); } @{$rawValue->{'keys'}} ]
    );

    $value->{'values'} = SOAP::Data->new (
        name => 'values',
        type => 'SOAP-ENC:Array',
        attr => {arrayType => 'xsd:string'},
        value => [ map { SOAP::Data->new(type => 'xsd:string', value => $_); } @{$rawValue->{'values'}} ]
    );


    return SOAP::Data->new (name => $name, type => $type, value => $value);
}

=pod

=item B<PlacementJob>

    my $myPlacementJob = {
        logicalFiles => [ 'string1', 'string2', ... ], 
        sourceSE => 'string', 
        destSE => 'string', 
        jobParams => $myTransferParams, 
        credential => 'string'
    };

=cut

sub __serialize__PlacementJob {
    my $name     = shift; # the name of the element
    my $rawValue = shift; # the Perl structure w/o type info

    # dealing with inheritance: optional parameters from the subclass
    # calling the superclass' serializer routine with its type and fields
    my $type     = shift || 'PlacementJob';
    my $value    = shift || {};

    
    $value->{'logicalFiles'} = SOAP::Data->new (
        name => 'logicalFiles',
        type => 'SOAP-ENC:Array',
        attr => {arrayType => 'xsd:string'},
        value => [ map { SOAP::Data->new(type => 'xsd:string', value => $_); } @{$rawValue->{'logicalFiles'}} ]
    );

    $value->{'sourceSE'} = SOAP::Data->new (
        name => 'sourceSE',
        type => 'xsd:string',
        value => $rawValue->{'sourceSE'}
    );

    $value->{'destSE'} = SOAP::Data->new (
        name => 'destSE',
        type => 'xsd:string',
        value => $rawValue->{'destSE'}
    );

    $value->{'jobParams'} = __serialize__TransferParams('jobParams', $rawValue->{'jobParams'});

    $value->{'credential'} = SOAP::Data->new (
        name => 'credential',
        type => 'xsd:string',
        value => $rawValue->{'credential'}
    );


    return SOAP::Data->new (name => $name, type => $type, value => $value);
}

=pod

=item B<TransferException>

    my $myTransferException = {
        message => 'string'
    };

=cut

sub __serialize__TransferException {
    my $name     = shift; # the name of the element
    my $rawValue = shift; # the Perl structure w/o type info

    # dealing with inheritance: optional parameters from the subclass
    # calling the superclass' serializer routine with its type and fields
    my $type     = shift || 'TransferException';
    my $value    = shift || {};

    
    $value->{'message'} = SOAP::Data->new (
        name => 'message',
        type => 'xsd:string',
        value => $rawValue->{'message'}
    );


    return SOAP::Data->new (name => $name, type => $type, value => $value);
}

=pod

=item B<InvalidArgumentException>

    my $myInvalidArgumentException = new TransferException (
        
    );

=cut

sub __serialize__InvalidArgumentException {
    my $name     = shift; # the name of the element
    my $rawValue = shift; # the Perl structure w/o type info

    # dealing with inheritance: optional parameters from the subclass
    # calling the superclass' serializer routine with its type and fields
    my $type     = shift || 'InvalidArgumentException';
    my $value    = shift || {};

    

    # calling the superclass' serializer for the rest
    return __serialize__TransferException ($name, $rawValue, $type, $value);
}

=pod

=item B<AuthorizationException>

    my $myAuthorizationException = new TransferException (
        
    );

=cut

sub __serialize__AuthorizationException {
    my $name     = shift; # the name of the element
    my $rawValue = shift; # the Perl structure w/o type info

    # dealing with inheritance: optional parameters from the subclass
    # calling the superclass' serializer routine with its type and fields
    my $type     = shift || 'AuthorizationException';
    my $value    = shift || {};

    

    # calling the superclass' serializer for the rest
    return __serialize__TransferException ($name, $rawValue, $type, $value);
}

=pod

=item B<ServiceBusyException>

    my $myServiceBusyException = new TransferException (
        
    );

=cut

sub __serialize__ServiceBusyException {
    my $name     = shift; # the name of the element
    my $rawValue = shift; # the Perl structure w/o type info

    # dealing with inheritance: optional parameters from the subclass
    # calling the superclass' serializer routine with its type and fields
    my $type     = shift || 'ServiceBusyException';
    my $value    = shift || {};

    

    # calling the superclass' serializer for the rest
    return __serialize__TransferException ($name, $rawValue, $type, $value);
}

=pod

=item B<InternalException>

    my $myInternalException = new TransferException (
        
    );

=cut

sub __serialize__InternalException {
    my $name     = shift; # the name of the element
    my $rawValue = shift; # the Perl structure w/o type info

    # dealing with inheritance: optional parameters from the subclass
    # calling the superclass' serializer routine with its type and fields
    my $type     = shift || 'InternalException';
    my $value    = shift || {};

    

    # calling the superclass' serializer for the rest
    return __serialize__TransferException ($name, $rawValue, $type, $value);
}

=pod

=item B<TransferJobElement>

    my $myTransferJobElement = {
        source => 'string', 
        dest => 'string'
    };

=cut

sub __serialize__TransferJobElement {
    my $name     = shift; # the name of the element
    my $rawValue = shift; # the Perl structure w/o type info

    # dealing with inheritance: optional parameters from the subclass
    # calling the superclass' serializer routine with its type and fields
    my $type     = shift || 'TransferJobElement';
    my $value    = shift || {};

    
    $value->{'source'} = SOAP::Data->new (
        name => 'source',
        type => 'xsd:string',
        value => $rawValue->{'source'}
    );

    $value->{'dest'} = SOAP::Data->new (
        name => 'dest',
        type => 'xsd:string',
        value => $rawValue->{'dest'}
    );


    return SOAP::Data->new (name => $name, type => $type, value => $value);
}

=pod

=item B<TransferJob>

    my $myTransferJob = {
        transferJobElements => [ $myTransferJobElement1, $myTransferJobElement2, ... ], 
        jobParams => $myTransferParams, 
        credential => 'string'
    };

=cut

sub __serialize__TransferJob {
    my $name     = shift; # the name of the element
    my $rawValue = shift; # the Perl structure w/o type info

    # dealing with inheritance: optional parameters from the subclass
    # calling the superclass' serializer routine with its type and fields
    my $type     = shift || 'TransferJob';
    my $value    = shift || {};

    
    $value->{'transferJobElements'} = SOAP::Data->new (
        name => 'transferJobElements',
        type => 'SOAP-ENC:Array',
        attr => {arrayType => 'TransferJobElement'},
        value => [ map { __serialize__TransferJobElement(undef, $_); } @{$rawValue->{'transferJobElements'}} ]
    );

    $value->{'jobParams'} = __serialize__TransferParams('jobParams', $rawValue->{'jobParams'});

    $value->{'credential'} = SOAP::Data->new (
        name => 'credential',
        type => 'xsd:string',
        value => $rawValue->{'credential'}
    );


    return SOAP::Data->new (name => $name, type => $type, value => $value);
}

=pod

=item B<JobStatus>

    my $myJobStatus = {
        jobID => 'string', 
        jobStatus => 'string', 
        channelName => 'string', 
        clientDN => 'string', 
        reason => 'string', 
        voName => 'string', 
        submitTime => $mylong, 
        numFiles => 9999, 
        priority => 9999
    };

=cut

sub __serialize__JobStatus {
    my $name     = shift; # the name of the element
    my $rawValue = shift; # the Perl structure w/o type info

    # dealing with inheritance: optional parameters from the subclass
    # calling the superclass' serializer routine with its type and fields
    my $type     = shift || 'JobStatus';
    my $value    = shift || {};

    
    $value->{'jobID'} = SOAP::Data->new (
        name => 'jobID',
        type => 'xsd:string',
        value => $rawValue->{'jobID'}
    );

    $value->{'jobStatus'} = SOAP::Data->new (
        name => 'jobStatus',
        type => 'xsd:string',
        value => $rawValue->{'jobStatus'}
    );

    $value->{'channelName'} = SOAP::Data->new (
        name => 'channelName',
        type => 'xsd:string',
        value => $rawValue->{'channelName'}
    );

    $value->{'clientDN'} = SOAP::Data->new (
        name => 'clientDN',
        type => 'xsd:string',
        value => $rawValue->{'clientDN'}
    );

    $value->{'reason'} = SOAP::Data->new (
        name => 'reason',
        type => 'xsd:string',
        value => $rawValue->{'reason'}
    );

    $value->{'voName'} = SOAP::Data->new (
        name => 'voName',
        type => 'xsd:string',
        value => $rawValue->{'voName'}
    );

    $value->{'submitTime'} = SOAP::Data->new (
        name => 'submitTime',
        type => 'xsd:long',
        value => $rawValue->{'submitTime'}
    );

    $value->{'numFiles'} = SOAP::Data->new (
        name => 'numFiles',
        type => 'xsd:int',
        value => $rawValue->{'numFiles'}
    );

    $value->{'priority'} = SOAP::Data->new (
        name => 'priority',
        type => 'xsd:int',
        value => $rawValue->{'priority'}
    );


    return SOAP::Data->new (name => $name, type => $type, value => $value);
}

=pod

=item B<FileTransferStatus>

    my $myFileTransferStatus = {
        logicalName => 'string', 
        sourceSURL => 'string', 
        destSURL => 'string', 
        transferFileState => 'string', 
        numFailures => 9999, 
        reason => 'string', 
        reason_class => 'string', 
        duration => $mylong
    };

=cut

sub __serialize__FileTransferStatus {
    my $name     = shift; # the name of the element
    my $rawValue = shift; # the Perl structure w/o type info

    # dealing with inheritance: optional parameters from the subclass
    # calling the superclass' serializer routine with its type and fields
    my $type     = shift || 'FileTransferStatus';
    my $value    = shift || {};

    
    $value->{'logicalName'} = SOAP::Data->new (
        name => 'logicalName',
        type => 'xsd:string',
        value => $rawValue->{'logicalName'}
    );

    $value->{'sourceSURL'} = SOAP::Data->new (
        name => 'sourceSURL',
        type => 'xsd:string',
        value => $rawValue->{'sourceSURL'}
    );

    $value->{'destSURL'} = SOAP::Data->new (
        name => 'destSURL',
        type => 'xsd:string',
        value => $rawValue->{'destSURL'}
    );

    $value->{'transferFileState'} = SOAP::Data->new (
        name => 'transferFileState',
        type => 'xsd:string',
        value => $rawValue->{'transferFileState'}
    );

    $value->{'numFailures'} = SOAP::Data->new (
        name => 'numFailures',
        type => 'xsd:int',
        value => $rawValue->{'numFailures'}
    );

    $value->{'reason'} = SOAP::Data->new (
        name => 'reason',
        type => 'xsd:string',
        value => $rawValue->{'reason'}
    );

    $value->{'reason_class'} = SOAP::Data->new (
        name => 'reason_class',
        type => 'xsd:string',
        value => $rawValue->{'reason_class'}
    );

    $value->{'duration'} = SOAP::Data->new (
        name => 'duration',
        type => 'xsd:long',
        value => $rawValue->{'duration'}
    );


    return SOAP::Data->new (name => $name, type => $type, value => $value);
}

=pod

=item B<NotExistsException>

    my $myNotExistsException = new TransferException (
        
    );

=cut

sub __serialize__NotExistsException {
    my $name     = shift; # the name of the element
    my $rawValue = shift; # the Perl structure w/o type info

    # dealing with inheritance: optional parameters from the subclass
    # calling the superclass' serializer routine with its type and fields
    my $type     = shift || 'NotExistsException';
    my $value    = shift || {};

    

    # calling the superclass' serializer for the rest
    return __serialize__TransferException ($name, $rawValue, $type, $value);
}

=pod

=item B<TransferJobSummary>

    my $myTransferJobSummary = {
        jobStatus => $myJobStatus, 
        numDone => 9999, 
        numActive => 9999, 
        numPending => 9999, 
        numCanceled => 9999, 
        numCanceling => 9999, 
        numFailed => 9999, 
        numFinished => 9999, 
        numSubmitted => 9999, 
        numHold => 9999, 
        numWaiting => 9999, 
        numCatalogFailed => 9999, 
        numRestarted => 9999
    };

=cut

sub __serialize__TransferJobSummary {
    my $name     = shift; # the name of the element
    my $rawValue = shift; # the Perl structure w/o type info

    # dealing with inheritance: optional parameters from the subclass
    # calling the superclass' serializer routine with its type and fields
    my $type     = shift || 'TransferJobSummary';
    my $value    = shift || {};

    
    $value->{'jobStatus'} = __serialize__JobStatus('jobStatus', $rawValue->{'jobStatus'});

    $value->{'numDone'} = SOAP::Data->new (
        name => 'numDone',
        type => 'xsd:int',
        value => $rawValue->{'numDone'}
    );

    $value->{'numActive'} = SOAP::Data->new (
        name => 'numActive',
        type => 'xsd:int',
        value => $rawValue->{'numActive'}
    );

    $value->{'numPending'} = SOAP::Data->new (
        name => 'numPending',
        type => 'xsd:int',
        value => $rawValue->{'numPending'}
    );

    $value->{'numCanceled'} = SOAP::Data->new (
        name => 'numCanceled',
        type => 'xsd:int',
        value => $rawValue->{'numCanceled'}
    );

    $value->{'numCanceling'} = SOAP::Data->new (
        name => 'numCanceling',
        type => 'xsd:int',
        value => $rawValue->{'numCanceling'}
    );

    $value->{'numFailed'} = SOAP::Data->new (
        name => 'numFailed',
        type => 'xsd:int',
        value => $rawValue->{'numFailed'}
    );

    $value->{'numFinished'} = SOAP::Data->new (
        name => 'numFinished',
        type => 'xsd:int',
        value => $rawValue->{'numFinished'}
    );

    $value->{'numSubmitted'} = SOAP::Data->new (
        name => 'numSubmitted',
        type => 'xsd:int',
        value => $rawValue->{'numSubmitted'}
    );

    $value->{'numHold'} = SOAP::Data->new (
        name => 'numHold',
        type => 'xsd:int',
        value => $rawValue->{'numHold'}
    );

    $value->{'numWaiting'} = SOAP::Data->new (
        name => 'numWaiting',
        type => 'xsd:int',
        value => $rawValue->{'numWaiting'}
    );

    $value->{'numCatalogFailed'} = SOAP::Data->new (
        name => 'numCatalogFailed',
        type => 'xsd:int',
        value => $rawValue->{'numCatalogFailed'}
    );

    $value->{'numRestarted'} = SOAP::Data->new (
        name => 'numRestarted',
        type => 'xsd:int',
        value => $rawValue->{'numRestarted'}
    );


    return SOAP::Data->new (name => $name, type => $type, value => $value);
}

=pod

=item B<CannotCancelException>

    my $myCannotCancelException = new TransferException (
        
    );

=cut

sub __serialize__CannotCancelException {
    my $name     = shift; # the name of the element
    my $rawValue = shift; # the Perl structure w/o type info

    # dealing with inheritance: optional parameters from the subclass
    # calling the superclass' serializer routine with its type and fields
    my $type     = shift || 'CannotCancelException';
    my $value    = shift || {};

    

    # calling the superclass' serializer for the rest
    return __serialize__TransferException ($name, $rawValue, $type, $value);
}

=pod

=item B<ExistsException>

    my $myExistsException = new TransferException (
        
    );

=cut

sub __serialize__ExistsException {
    my $name     = shift; # the name of the element
    my $rawValue = shift; # the Perl structure w/o type info

    # dealing with inheritance: optional parameters from the subclass
    # calling the superclass' serializer routine with its type and fields
    my $type     = shift || 'ExistsException';
    my $value    = shift || {};

    

    # calling the superclass' serializer for the rest
    return __serialize__TransferException ($name, $rawValue, $type, $value);
}

=pod

=item B<StringPair>

    my $myStringPair = {
        string1 => 'string', 
        string2 => 'string'
    };

=cut

sub __serialize__StringPair {
    my $name     = shift; # the name of the element
    my $rawValue = shift; # the Perl structure w/o type info

    # dealing with inheritance: optional parameters from the subclass
    # calling the superclass' serializer routine with its type and fields
    my $type     = shift || 'StringPair';
    my $value    = shift || {};

    
    $value->{'string1'} = SOAP::Data->new (
        name => 'string1',
        type => 'xsd:string',
        value => $rawValue->{'string1'}
    );

    $value->{'string2'} = SOAP::Data->new (
        name => 'string2',
        type => 'xsd:string',
        value => $rawValue->{'string2'}
    );


    return SOAP::Data->new (name => $name, type => $type, value => $value);
}

=pod

=item B<Roles>

    my $myRoles = {
        clientDN => 'string', 
        serviceAdmin => 'string', 
        submitter => 'string', 
        VOManager => [ $myStringPair1, $myStringPair2, ... ], 
        channelManager => [ $myStringPair1, $myStringPair2, ... ]
    };

=cut

sub __serialize__Roles {
    my $name     = shift; # the name of the element
    my $rawValue = shift; # the Perl structure w/o type info

    # dealing with inheritance: optional parameters from the subclass
    # calling the superclass' serializer routine with its type and fields
    my $type     = shift || 'Roles';
    my $value    = shift || {};

    
    $value->{'clientDN'} = SOAP::Data->new (
        name => 'clientDN',
        type => 'xsd:string',
        value => $rawValue->{'clientDN'}
    );

    $value->{'serviceAdmin'} = SOAP::Data->new (
        name => 'serviceAdmin',
        type => 'xsd:string',
        value => $rawValue->{'serviceAdmin'}
    );

    $value->{'submitter'} = SOAP::Data->new (
        name => 'submitter',
        type => 'xsd:string',
        value => $rawValue->{'submitter'}
    );

    $value->{'VOManager'} = SOAP::Data->new (
        name => 'VOManager',
        type => 'SOAP-ENC:Array',
        attr => {arrayType => 'StringPair'},
        value => [ map { __serialize__StringPair(undef, $_); } @{$rawValue->{'VOManager'}} ]
    );

    $value->{'channelManager'} = SOAP::Data->new (
        name => 'channelManager',
        type => 'SOAP-ENC:Array',
        attr => {arrayType => 'StringPair'},
        value => [ map { __serialize__StringPair(undef, $_); } @{$rawValue->{'channelManager'}} ]
    );


    return SOAP::Data->new (name => $name, type => $type, value => $value);
}

=pod

=item B<ArrayOf_soapenc_string>

    my $myArrayOf_soapenc_string = [ 'string1', 'string2', ...];

=cut

sub __serialize__ArrayOf_soapenc_string {
    my $name     = shift; # the name of the element
    my $rawValue = shift; # the Perl array w/o type info
    my $type     = 'ArrayOf_soapenc_string';
    my $value    = {};

    return SOAP::Data->new (
        name => $name,
        type => 'SOAP-ENC:Array',
        attr => {arrayType => 'xsd:string'},
        value => [ map { SOAP::Data->new(type => 'xsd:string', value => $_); } @{$rawValue} ]
    );
}

=pod

=item B<ArrayOf_tns3_JobStatus>

    my $myArrayOf_tns3_JobStatus = [ $myJobStatus1, $myJobStatus2, ... ];

=cut

sub __serialize__ArrayOf_tns3_JobStatus {
    my $name     = shift; # the name of the element
    my $rawValue = shift; # the Perl array w/o type info
    my $type     = 'ArrayOf_tns3_JobStatus';
    my $value    = {};

    return SOAP::Data->new (
        name => $name,
        type => 'SOAP-ENC:Array',
        attr => {arrayType => 'JobStatus'},
        value => [ map { __serialize__JobStatus(undef, $_); } @{$rawValue} ]
    );
}

=pod

=item B<ArrayOf_tns3_FileTransferStatus>

    my $myArrayOf_tns3_FileTransferStatus = [ $myFileTransferStatus1, $myFileTransferStatus2, ... ];

=cut

sub __serialize__ArrayOf_tns3_FileTransferStatus {
    my $name     = shift; # the name of the element
    my $rawValue = shift; # the Perl array w/o type info
    my $type     = 'ArrayOf_tns3_FileTransferStatus';
    my $value    = {};

    return SOAP::Data->new (
        name => $name,
        type => 'SOAP-ENC:Array',
        attr => {arrayType => 'FileTransferStatus'},
        value => [ map { __serialize__FileTransferStatus(undef, $_); } @{$rawValue} ]
    );
}



=pod

=back

=head1 SEE ALSO

L<GLite::HTTPS>

=head1 AUTHORS

Copyright (c) 2004 CERN, on behalf of the EU EGEE project.
For license conditions see LICENSE file or
L<http://www.edg.org/license.html>.

=cut

1;
