
package GLite::Data::FileTransferStats;

use strict;
no strict 'refs';
use SOAP::Lite;
use GLite::HTTPS;
use Data::Dumper;

=head1 NAME

GLite::Data::FileTransferStats

=head1 DESCRIPTION

GLite::Data::FileCatalog module provides a Perl client
library for the B<FileTransferStats> interface.

=head1 METHODS

The methods I<die> if there was a SOAP fault.
The fault string and details are added to the I<die> message.

=over 4

=item B<new($URL)>

Creates an FileTransferStats object, which is initialized with the
approriate SOAP endpoint. If the URL uses https protocol,
then it will do the HTTPS initialization (locating proxy
certificate) as well.

Note: you have to include the VO name in the URL!

    my $srv = GLite::Data::FileTransferStats->new('https://service.glite.org:8443/example');

=cut


sub new
{
    my $proto = shift;
    my $class = ref($proto) || $proto;
    my $self  = {};
    $self->{SOAP} = undef;
    bless( $self, $class );

    my $url = shift;

    defined $url or 
      print STDERR "FileTransferStats endpoint was not defined!\n" and return;

    GLite::HTTPS::setEnv() if $url =~ /^https:/i;

    $self->{SOAP} = new SOAP::Lite (
        uri => 'org.glite.data.catalog',
        proxy => $url,
        on_fault => sub { my($soap, $res) = @_;
            die $soap->transport->status, "\n" unless(ref $res);
            local $Data::Dumper::Pad = "    Details: ";
            die $res->faultcode(),": ",$res->faultstring(),"\n",
                Dumper($res->faultdetail()), "\n";
        }
    );

    
    # namespace definitions for 'http://glite.org/wsdl/services/org.glite.data.transfer.stats'
    
    $self->{SOAP}->serializer()->maptype->{'ArrayOf_soapenc_string'} = "http://glite.org/wsdl/services/org.glite.data.transfer.stats";

    $self->{SOAP}->serializer()->maptype->{'ArrayOf_tns3_TransferSummary'} = "http://glite.org/wsdl/services/org.glite.data.transfer.stats";

    $self->{SOAP}->serializer()->maptype->{'ArrayOf_tns3_TransferActivity'} = "http://glite.org/wsdl/services/org.glite.data.transfer.stats";

    $self->{SOAP}->serializer()->maptype->{'ArrayOf_tns3_TransferAgent'} = "http://glite.org/wsdl/services/org.glite.data.transfer.stats";

    # namespace definitions for 'http://transfer.data.glite.org'
    
    $self->{SOAP}->serializer()->maptype->{'TransferSnapshot'} = "http://transfer.data.glite.org";

    $self->{SOAP}->serializer()->maptype->{'TransferSummary'} = "http://transfer.data.glite.org";

    $self->{SOAP}->serializer()->maptype->{'TransferException'} = "http://transfer.data.glite.org";

    $self->{SOAP}->serializer()->maptype->{'AuthorizationException'} = "http://transfer.data.glite.org";

    $self->{SOAP}->serializer()->maptype->{'InvalidArgumentException'} = "http://transfer.data.glite.org";

    $self->{SOAP}->serializer()->maptype->{'ServiceBusyException'} = "http://transfer.data.glite.org";

    $self->{SOAP}->serializer()->maptype->{'InternalException'} = "http://transfer.data.glite.org";

    $self->{SOAP}->serializer()->maptype->{'TransferActivityPeriod'} = "http://transfer.data.glite.org";

    $self->{SOAP}->serializer()->maptype->{'TransferActivity'} = "http://transfer.data.glite.org";

    $self->{SOAP}->serializer()->maptype->{'TransferAgent'} = "http://transfer.data.glite.org";


    return $self;
}

    
=pod

=item B<TransferSummary[] getChannelSummary(string channelName, string[] voNames)>

=cut

sub getChannelSummary {
    my ($self) = shift;
    my $result = $self->{SOAP}->getChannelSummary(
        SOAP::Data->new(name => 'channelName', type => 'xsd:string', value => shift), 
        __serialize__ArrayOf_soapenc_string('voNames', shift)
    )->result();
    return $result;
}

=pod

=item B<TransferSummary[] getVOSummary(string voName, string[] channelNames)>

=cut

sub getVOSummary {
    my ($self) = shift;
    my $result = $self->{SOAP}->getVOSummary(
        SOAP::Data->new(name => 'voName', type => 'xsd:string', value => shift), 
        __serialize__ArrayOf_soapenc_string('channelNames', shift)
    )->result();
    return $result;
}

=pod

=item B<TransferActivity[] getChannelActivity(string channelName, string[] voNames)>

=cut

sub getChannelActivity {
    my ($self) = shift;
    my $result = $self->{SOAP}->getChannelActivity(
        SOAP::Data->new(name => 'channelName', type => 'xsd:string', value => shift), 
        __serialize__ArrayOf_soapenc_string('voNames', shift)
    )->result();
    return $result;
}

=pod

=item B<TransferActivity[] getVOActivity(string voName, string[] channelNames)>

=cut

sub getVOActivity {
    my ($self) = shift;
    my $result = $self->{SOAP}->getVOActivity(
        SOAP::Data->new(name => 'voName', type => 'xsd:string', value => shift), 
        __serialize__ArrayOf_soapenc_string('channelNames', shift)
    )->result();
    return $result;
}

=pod

=item B<TransferAgent[] getTransferAgents()>

=cut

sub getTransferAgents {
    my ($self) = shift;
    my $result = $self->{SOAP}->getTransferAgents(
    )->result();
    return $result;
}

=pod

=item B<string getVersion()>

=cut

sub getVersion {
    my ($self) = shift;
    my $result = $self->{SOAP}->getVersion(
    )->result();
    return $result;
}

=pod

=item B<string getSchemaVersion()>

=cut

sub getSchemaVersion {
    my ($self) = shift;
    my $result = $self->{SOAP}->getSchemaVersion(
    )->result();
    return $result;
}

=pod

=item B<string getInterfaceVersion()>

=cut

sub getInterfaceVersion {
    my ($self) = shift;
    my $result = $self->{SOAP}->getInterfaceVersion(
    )->result();
    return $result;
}

=pod

=item B<string getServiceMetadata(string key)>

=cut

sub getServiceMetadata {
    my ($self) = shift;
    my $result = $self->{SOAP}->getServiceMetadata(
        SOAP::Data->new(name => 'key', type => 'xsd:string', value => shift)
    )->result();
    return $result;
}


=pod

=back

=head1 TYPES

=over 4

=cut


    
=pod

=item B<ArrayOf_soapenc_string>

    my $myArrayOf_soapenc_string = [ 'string1', 'string2', ...];

=cut

sub __serialize__ArrayOf_soapenc_string {
    my $name     = shift; # the name of the element
    my $rawValue = shift; # the Perl array w/o type info
    my $type     = 'ArrayOf_soapenc_string';
    my $value    = {};

    return SOAP::Data->new (
        name => $name,
        type => 'SOAP-ENC:Array',
        attr => {arrayType => 'xsd:string'},
        value => [ map { SOAP::Data->new(type => 'xsd:string', value => $_); } @{$rawValue} ]
    );
}

=pod

=item B<ArrayOf_tns3_TransferSummary>

    my $myArrayOf_tns3_TransferSummary = [ $myTransferSummary1, $myTransferSummary2, ... ];

=cut

sub __serialize__ArrayOf_tns3_TransferSummary {
    my $name     = shift; # the name of the element
    my $rawValue = shift; # the Perl array w/o type info
    my $type     = 'ArrayOf_tns3_TransferSummary';
    my $value    = {};

    return SOAP::Data->new (
        name => $name,
        type => 'SOAP-ENC:Array',
        attr => {arrayType => 'TransferSummary'},
        value => [ map { __serialize__TransferSummary(undef, $_); } @{$rawValue} ]
    );
}

=pod

=item B<ArrayOf_tns3_TransferActivity>

    my $myArrayOf_tns3_TransferActivity = [ $myTransferActivity1, $myTransferActivity2, ... ];

=cut

sub __serialize__ArrayOf_tns3_TransferActivity {
    my $name     = shift; # the name of the element
    my $rawValue = shift; # the Perl array w/o type info
    my $type     = 'ArrayOf_tns3_TransferActivity';
    my $value    = {};

    return SOAP::Data->new (
        name => $name,
        type => 'SOAP-ENC:Array',
        attr => {arrayType => 'TransferActivity'},
        value => [ map { __serialize__TransferActivity(undef, $_); } @{$rawValue} ]
    );
}

=pod

=item B<ArrayOf_tns3_TransferAgent>

    my $myArrayOf_tns3_TransferAgent = [ $myTransferAgent1, $myTransferAgent2, ... ];

=cut

sub __serialize__ArrayOf_tns3_TransferAgent {
    my $name     = shift; # the name of the element
    my $rawValue = shift; # the Perl array w/o type info
    my $type     = 'ArrayOf_tns3_TransferAgent';
    my $value    = {};

    return SOAP::Data->new (
        name => $name,
        type => 'SOAP-ENC:Array',
        attr => {arrayType => 'TransferAgent'},
        value => [ map { __serialize__TransferAgent(undef, $_); } @{$rawValue} ]
    );
}

=pod

=item B<TransferSnapshot>

    my $myTransferSnapshot = {
        time => $mydateTime, 
        numSubmittedJobs => 9999, 
        numPendingJobs => 9999, 
        numActiveJobs => 9999, 
        numDoneJobs => 9999, 
        numHoldJobs => 9999, 
        numFailedJobs => 9999, 
        numCanceledJobs => 9999, 
        numCancelingJobs => 9999, 
        numFinishedDirtyJobs => 9999, 
        numFinishedJobs => 9999, 
        numSubmittedFiles => 9999, 
        numPendingFiles => 9999, 
        numActiveFiles => 9999, 
        numDoneFiles => 9999, 
        numWaitingFiles => 9999, 
        numHoldFiles => 9999, 
        numCancelingFiles => 9999, 
        numCanceledFiles => 9999, 
        numFailedFiles => 9999, 
        numFinishedFiles => 9999, 
        numCatalogFailedFiles => 9999
    };

=cut

sub __serialize__TransferSnapshot {
    my $name     = shift; # the name of the element
    my $rawValue = shift; # the Perl structure w/o type info

    # dealing with inheritance: optional parameters from the subclass
    # calling the superclass' serializer routine with its type and fields
    my $type     = shift || 'TransferSnapshot';
    my $value    = shift || {};

    
    $value->{'time'} = SOAP::Data->new (
        name => 'time',
        type => 'xsd:dateTime',
        value => $rawValue->{'time'}
    );

    $value->{'numSubmittedJobs'} = SOAP::Data->new (
        name => 'numSubmittedJobs',
        type => 'xsd:int',
        value => $rawValue->{'numSubmittedJobs'}
    );

    $value->{'numPendingJobs'} = SOAP::Data->new (
        name => 'numPendingJobs',
        type => 'xsd:int',
        value => $rawValue->{'numPendingJobs'}
    );

    $value->{'numActiveJobs'} = SOAP::Data->new (
        name => 'numActiveJobs',
        type => 'xsd:int',
        value => $rawValue->{'numActiveJobs'}
    );

    $value->{'numDoneJobs'} = SOAP::Data->new (
        name => 'numDoneJobs',
        type => 'xsd:int',
        value => $rawValue->{'numDoneJobs'}
    );

    $value->{'numHoldJobs'} = SOAP::Data->new (
        name => 'numHoldJobs',
        type => 'xsd:int',
        value => $rawValue->{'numHoldJobs'}
    );

    $value->{'numFailedJobs'} = SOAP::Data->new (
        name => 'numFailedJobs',
        type => 'xsd:int',
        value => $rawValue->{'numFailedJobs'}
    );

    $value->{'numCanceledJobs'} = SOAP::Data->new (
        name => 'numCanceledJobs',
        type => 'xsd:int',
        value => $rawValue->{'numCanceledJobs'}
    );

    $value->{'numCancelingJobs'} = SOAP::Data->new (
        name => 'numCancelingJobs',
        type => 'xsd:int',
        value => $rawValue->{'numCancelingJobs'}
    );

    $value->{'numFinishedDirtyJobs'} = SOAP::Data->new (
        name => 'numFinishedDirtyJobs',
        type => 'xsd:int',
        value => $rawValue->{'numFinishedDirtyJobs'}
    );

    $value->{'numFinishedJobs'} = SOAP::Data->new (
        name => 'numFinishedJobs',
        type => 'xsd:int',
        value => $rawValue->{'numFinishedJobs'}
    );

    $value->{'numSubmittedFiles'} = SOAP::Data->new (
        name => 'numSubmittedFiles',
        type => 'xsd:int',
        value => $rawValue->{'numSubmittedFiles'}
    );

    $value->{'numPendingFiles'} = SOAP::Data->new (
        name => 'numPendingFiles',
        type => 'xsd:int',
        value => $rawValue->{'numPendingFiles'}
    );

    $value->{'numActiveFiles'} = SOAP::Data->new (
        name => 'numActiveFiles',
        type => 'xsd:int',
        value => $rawValue->{'numActiveFiles'}
    );

    $value->{'numDoneFiles'} = SOAP::Data->new (
        name => 'numDoneFiles',
        type => 'xsd:int',
        value => $rawValue->{'numDoneFiles'}
    );

    $value->{'numWaitingFiles'} = SOAP::Data->new (
        name => 'numWaitingFiles',
        type => 'xsd:int',
        value => $rawValue->{'numWaitingFiles'}
    );

    $value->{'numHoldFiles'} = SOAP::Data->new (
        name => 'numHoldFiles',
        type => 'xsd:int',
        value => $rawValue->{'numHoldFiles'}
    );

    $value->{'numCancelingFiles'} = SOAP::Data->new (
        name => 'numCancelingFiles',
        type => 'xsd:int',
        value => $rawValue->{'numCancelingFiles'}
    );

    $value->{'numCanceledFiles'} = SOAP::Data->new (
        name => 'numCanceledFiles',
        type => 'xsd:int',
        value => $rawValue->{'numCanceledFiles'}
    );

    $value->{'numFailedFiles'} = SOAP::Data->new (
        name => 'numFailedFiles',
        type => 'xsd:int',
        value => $rawValue->{'numFailedFiles'}
    );

    $value->{'numFinishedFiles'} = SOAP::Data->new (
        name => 'numFinishedFiles',
        type => 'xsd:int',
        value => $rawValue->{'numFinishedFiles'}
    );

    $value->{'numCatalogFailedFiles'} = SOAP::Data->new (
        name => 'numCatalogFailedFiles',
        type => 'xsd:int',
        value => $rawValue->{'numCatalogFailedFiles'}
    );


    return SOAP::Data->new (name => $name, type => $type, value => $value);
}

=pod

=item B<TransferSummary>

    my $myTransferSummary = {
        channelName => 'string', 
        voName => 'string', 
        snapshots => [ $myTransferSnapshot1, $myTransferSnapshot2, ... ]
    };

=cut

sub __serialize__TransferSummary {
    my $name     = shift; # the name of the element
    my $rawValue = shift; # the Perl structure w/o type info

    # dealing with inheritance: optional parameters from the subclass
    # calling the superclass' serializer routine with its type and fields
    my $type     = shift || 'TransferSummary';
    my $value    = shift || {};

    
    $value->{'channelName'} = SOAP::Data->new (
        name => 'channelName',
        type => 'xsd:string',
        value => $rawValue->{'channelName'}
    );

    $value->{'voName'} = SOAP::Data->new (
        name => 'voName',
        type => 'xsd:string',
        value => $rawValue->{'voName'}
    );

    $value->{'snapshots'} = SOAP::Data->new (
        name => 'snapshots',
        type => 'SOAP-ENC:Array',
        attr => {arrayType => 'TransferSnapshot'},
        value => [ map { __serialize__TransferSnapshot(undef, $_); } @{$rawValue->{'snapshots'}} ]
    );


    return SOAP::Data->new (name => $name, type => $type, value => $value);
}

=pod

=item B<TransferException>

    my $myTransferException = {
        message => 'string'
    };

=cut

sub __serialize__TransferException {
    my $name     = shift; # the name of the element
    my $rawValue = shift; # the Perl structure w/o type info

    # dealing with inheritance: optional parameters from the subclass
    # calling the superclass' serializer routine with its type and fields
    my $type     = shift || 'TransferException';
    my $value    = shift || {};

    
    $value->{'message'} = SOAP::Data->new (
        name => 'message',
        type => 'xsd:string',
        value => $rawValue->{'message'}
    );


    return SOAP::Data->new (name => $name, type => $type, value => $value);
}

=pod

=item B<AuthorizationException>

    my $myAuthorizationException = new TransferException (
        
    );

=cut

sub __serialize__AuthorizationException {
    my $name     = shift; # the name of the element
    my $rawValue = shift; # the Perl structure w/o type info

    # dealing with inheritance: optional parameters from the subclass
    # calling the superclass' serializer routine with its type and fields
    my $type     = shift || 'AuthorizationException';
    my $value    = shift || {};

    

    # calling the superclass' serializer for the rest
    return __serialize__TransferException ($name, $rawValue, $type, $value);
}

=pod

=item B<InvalidArgumentException>

    my $myInvalidArgumentException = new TransferException (
        
    );

=cut

sub __serialize__InvalidArgumentException {
    my $name     = shift; # the name of the element
    my $rawValue = shift; # the Perl structure w/o type info

    # dealing with inheritance: optional parameters from the subclass
    # calling the superclass' serializer routine with its type and fields
    my $type     = shift || 'InvalidArgumentException';
    my $value    = shift || {};

    

    # calling the superclass' serializer for the rest
    return __serialize__TransferException ($name, $rawValue, $type, $value);
}

=pod

=item B<ServiceBusyException>

    my $myServiceBusyException = new TransferException (
        
    );

=cut

sub __serialize__ServiceBusyException {
    my $name     = shift; # the name of the element
    my $rawValue = shift; # the Perl structure w/o type info

    # dealing with inheritance: optional parameters from the subclass
    # calling the superclass' serializer routine with its type and fields
    my $type     = shift || 'ServiceBusyException';
    my $value    = shift || {};

    

    # calling the superclass' serializer for the rest
    return __serialize__TransferException ($name, $rawValue, $type, $value);
}

=pod

=item B<InternalException>

    my $myInternalException = new TransferException (
        
    );

=cut

sub __serialize__InternalException {
    my $name     = shift; # the name of the element
    my $rawValue = shift; # the Perl structure w/o type info

    # dealing with inheritance: optional parameters from the subclass
    # calling the superclass' serializer routine with its type and fields
    my $type     = shift || 'InternalException';
    my $value    = shift || {};

    

    # calling the superclass' serializer for the rest
    return __serialize__TransferException ($name, $rawValue, $type, $value);
}

=pod

=item B<TransferActivityPeriod>

    my $myTransferActivityPeriod = {
        startTime => $mydateTime, 
        endTime => $mydateTime, 
        averageRate => $myfloat, 
        bytesWritten => $mylong
    };

=cut

sub __serialize__TransferActivityPeriod {
    my $name     = shift; # the name of the element
    my $rawValue = shift; # the Perl structure w/o type info

    # dealing with inheritance: optional parameters from the subclass
    # calling the superclass' serializer routine with its type and fields
    my $type     = shift || 'TransferActivityPeriod';
    my $value    = shift || {};

    
    $value->{'startTime'} = SOAP::Data->new (
        name => 'startTime',
        type => 'xsd:dateTime',
        value => $rawValue->{'startTime'}
    );

    $value->{'endTime'} = SOAP::Data->new (
        name => 'endTime',
        type => 'xsd:dateTime',
        value => $rawValue->{'endTime'}
    );

    $value->{'averageRate'} = SOAP::Data->new (
        name => 'averageRate',
        type => 'xsd:float',
        value => $rawValue->{'averageRate'}
    );

    $value->{'bytesWritten'} = SOAP::Data->new (
        name => 'bytesWritten',
        type => 'xsd:long',
        value => $rawValue->{'bytesWritten'}
    );


    return SOAP::Data->new (name => $name, type => $type, value => $value);
}

=pod

=item B<TransferActivity>

    my $myTransferActivity = {
        channelName => 'string', 
        voName => 'string', 
        activityPeriods => [ $myTransferActivityPeriod1, $myTransferActivityPeriod2, ... ]
    };

=cut

sub __serialize__TransferActivity {
    my $name     = shift; # the name of the element
    my $rawValue = shift; # the Perl structure w/o type info

    # dealing with inheritance: optional parameters from the subclass
    # calling the superclass' serializer routine with its type and fields
    my $type     = shift || 'TransferActivity';
    my $value    = shift || {};

    
    $value->{'channelName'} = SOAP::Data->new (
        name => 'channelName',
        type => 'xsd:string',
        value => $rawValue->{'channelName'}
    );

    $value->{'voName'} = SOAP::Data->new (
        name => 'voName',
        type => 'xsd:string',
        value => $rawValue->{'voName'}
    );

    $value->{'activityPeriods'} = SOAP::Data->new (
        name => 'activityPeriods',
        type => 'SOAP-ENC:Array',
        attr => {arrayType => 'TransferActivityPeriod'},
        value => [ map { __serialize__TransferActivityPeriod(undef, $_); } @{$rawValue->{'activityPeriods'}} ]
    );


    return SOAP::Data->new (name => $name, type => $type, value => $value);
}

=pod

=item B<TransferAgent>

    my $myTransferAgent = {
        name => 'string', 
        DN => 'string', 
        host => 'string', 
        type => 'string', 
        lastActive => $mydateTime, 
        state => 'string', 
        version => 'string', 
        contact => 'string'
    };

=cut

sub __serialize__TransferAgent {
    my $name     = shift; # the name of the element
    my $rawValue = shift; # the Perl structure w/o type info

    # dealing with inheritance: optional parameters from the subclass
    # calling the superclass' serializer routine with its type and fields
    my $type     = shift || 'TransferAgent';
    my $value    = shift || {};

    
    $value->{'name'} = SOAP::Data->new (
        name => 'name',
        type => 'xsd:string',
        value => $rawValue->{'name'}
    );

    $value->{'DN'} = SOAP::Data->new (
        name => 'DN',
        type => 'xsd:string',
        value => $rawValue->{'DN'}
    );

    $value->{'host'} = SOAP::Data->new (
        name => 'host',
        type => 'xsd:string',
        value => $rawValue->{'host'}
    );

    $value->{'type'} = SOAP::Data->new (
        name => 'type',
        type => 'xsd:string',
        value => $rawValue->{'type'}
    );

    $value->{'lastActive'} = SOAP::Data->new (
        name => 'lastActive',
        type => 'xsd:dateTime',
        value => $rawValue->{'lastActive'}
    );

    $value->{'state'} = SOAP::Data->new (
        name => 'state',
        type => 'xsd:string',
        value => $rawValue->{'state'}
    );

    $value->{'version'} = SOAP::Data->new (
        name => 'version',
        type => 'xsd:string',
        value => $rawValue->{'version'}
    );

    $value->{'contact'} = SOAP::Data->new (
        name => 'contact',
        type => 'xsd:string',
        value => $rawValue->{'contact'}
    );


    return SOAP::Data->new (name => $name, type => $type, value => $value);
}



=pod

=back

=head1 SEE ALSO

L<GLite::HTTPS>

=head1 AUTHORS

Copyright (c) 2004 CERN, on behalf of the EU EGEE project.
For license conditions see LICENSE file or
L<http://www.edg.org/license.html>.

=cut

1;
